==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridSizeChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSizeChangedEventArgsDescription } from "./GridSizeChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSizeChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSizeChangedEventArgsDescriptionMetadata, _super);
    function GridSizeChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSizeChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSizeChangedEventArgsDescriptionMetadata.a == null) {
            GridSizeChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSizeChangedEventArgsDescriptionMetadata.c(GridSizeChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridSizeChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridSizeChangedEventArgsDescriptionMetadata.a);
    };
    GridSizeChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Width", "Number:double");
        a.item("Height", "Number:double");
    };
    GridSizeChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSizeChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridSizeChangedEventArgs", function () { return new GridSizeChangedEventArgsDescription(); });
        a.t("GridSizeChangedEventArgs", GridSizeChangedEventArgsDescriptionMetadata.a);
    };
    GridSizeChangedEventArgsDescriptionMetadata.$t = markType(GridSizeChangedEventArgsDescriptionMetadata, 'GridSizeChangedEventArgsDescriptionMetadata');
    GridSizeChangedEventArgsDescriptionMetadata.a = null;
    return GridSizeChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSizeChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridSizeChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSizeChangedEventArgsDescription } from "./GridSizeChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSizeChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSizeChangedEventArgsDescriptionMetadata, _super);
    function GridSizeChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSizeChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSizeChangedEventArgsDescriptionMetadata.a == null) {
            GridSizeChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSizeChangedEventArgsDescriptionMetadata.c(GridSizeChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSizeChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSizeChangedEventArgsDescriptionMetadata.a);
    };
    GridSizeChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Width", "Number:double");
        a.item("Height", "Number:double");
    };
    GridSizeChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSizeChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSizeChangedEventArgs", function () { return new GridSizeChangedEventArgsDescription(); });
        a.z("GridSizeChangedEventArgs", GridSizeChangedEventArgsDescriptionMetadata.a);
    };
    GridSizeChangedEventArgsDescriptionMetadata.$t = markType(GridSizeChangedEventArgsDescriptionMetadata, 'GridSizeChangedEventArgsDescriptionMetadata');
    GridSizeChangedEventArgsDescriptionMetadata.a = null;
    return GridSizeChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSizeChangedEventArgsDescriptionMetadata };
